<!-- markdownlint-disable MD033 MD041 -->

<p align="center">
  <a href="https://holded.com" target="_blank">
    <img src="https://www.holded.com/wp-content/uploads/2020/05/Holded_H_Logo_R_header.png" />
  </a>
  <h1 align="center">Holded Mobile UI</h1>
</p>

This is a component library developed and mantained by [Holded Mobile Team](https://github.com/orgs/holdedhub/teams/mobile/members) to be used in different mobile projects.

---

## Installation

Using npm

```sh
npm install holded-mobile-ui
```

Using yarn

```sh
yarn add holded-mobile-ui
```

- This library has some important dependencies like [react-native-svg](https://github.com/react-native-svg/react-native-svg), [consistencss](https://github.com/mateosilguero/consistencss) and [Roboto Font](https://fonts.google.com/specimen/Roboto)

---

## Example

```tsx
import { View } from 'react-native';
import { Text, TextVariant } from 'holded-mobile-ui';

const App = () => (
  <View>
    <Text variant={TextVariant.Hero}>This is a HERO text</Text>
  </View>
);
```

---

## Documentation

- [ActionSheet](./docs/ActionSheet.md)
- [Avatar](./docs/Avatar.md)
- [AwesomeIcon](./docs/AwesomeIcon.md)
- [BottomModal](./docs/BottomModal.md)
- [Button](./docs/Button.md)
- [Colors](./docs/Colors.md)
- [FilterChip](./docs/FilterChip.md)
- [Icon](./docs/Icon.md)
- [Input](./docs/Input.md)
- [Layout](./docs/Layout.md)
- [Loader](./docs/Loader.md)
- [Modal](./docs/Modal.md)
- [Select](./docs/Select.md)
- [Tabs](./docs/Tabs.md)
- [Text](./docs/Text.md)

---

## For development

To get started with the project, run `yarn bootstrap` in the root directory to install the dependencies:

```sh
yarn bootstrap
```

While developing, you can run the [example app](/example/) to test your changes.

To start the packager:

```sh
yarn example start
```

---

## UI Library App

This app is for internal use and visual testing. We distribute it via App Center, here you can request access to it.

<table>
  <tr>
    <td align="center">
      <a href="https://install.appcenter.ms/orgs/holdedtech/apps/mobileui-android">
        <img src="./docs/images/mobile-android-qr.png" width="152px" alt=""/>
        <br />
        <sub>
          <b>
            <a href="https://install.appcenter.ms/orgs/holdedtech/apps/mobileui-android" title="Android">🤖 &nbsp; Android</a>
          </b>
        </sub>
      </a>
    </td>
    <td align="center">
      <a href="https://install.appcenter.ms/orgs/holdedtech/apps/mobileui-ios">
        <img src="./docs/images/mobile-ios-qr.png" width="152px" alt=""/>
        <br />
        <sub>
          <b>
            <a href="https://install.appcenter.ms/orgs/holdedtech/apps/mobileui-ios" title="iOS">🍏 &nbsp; iOS</a>
          </b>
        </sub>
      </a>
    </td>
  </tr>
</table>

---

### Commit message convention

We follow the [conventional commits specification](https://www.conventionalcommits.org/en) for our commit messages:

- `fix`: bug fixes, e.g. fix crash due to deprecated method.
- `feat`: new features, e.g. add new method to the module.
- `refactor`: code refactor, e.g. migrate from class components to hooks.
- `docs`: changes into documentation, e.g. add usage example for the module..
- `test`: adding or updating tests, eg add integration tests using detox.
- `chore`: tooling changes, e.g. change CI config.

Our pre-commit hooks verify that your commit message matches this format when committing.
