"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _lodash = require("lodash");

var _react = _interopRequireWildcard(require("react"));

var _reactNative = require("react-native");

var _reactNativeFastImage = _interopRequireDefault(require("react-native-fast-image"));

var _Avatar = require("./Avatar.types");

var _styles = require("../../styles");

var _Colors = _interopRequireWildcard(require("../../Colors"));

var _Images = _interopRequireDefault(require("../../Images"));

var _Text = _interopRequireWildcard(require("../Text"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

const Avatar = ({
  color = _Colors.default.iconic,
  image = null,
  name,
  shape = _Avatar.AvatarShape.RoundedSquare,
  size = _Avatar.AvatarSize.Tiny,
  style,
  type = _Avatar.AvatarType.User,
  useFirstLetter = false
}) => {
  const [hasError, setHasError] = (0, _react.useState)(false);
  const source = (0, _react.useMemo)(() => image && !(0, _lodash.isEmpty)(image) && !hasError ? {
    uri: image
  } : _Images.default.HOLDED_LOGO, [image, hasError]);

  const handleError = () => setHasError(true);

  const textProps = (0, _react.useMemo)(() => {
    switch (size) {
      case _Avatar.AvatarSize.Tiny:
      case _Avatar.AvatarSize.Small:
      default:
        return {
          variant: _Text.TextVariant.ExtraSmall
        };

      case _Avatar.AvatarSize.Medium:
        return {
          variant: _Text.TextVariant.Small,
          weight: _Text.FontWeight.Bold
        };

      case _Avatar.AvatarSize.Large:
        return {
          variant: _Text.TextVariant.Large,
          weight: _Text.FontWeight.Bold
        };
    }
  }, [size]);

  if (((0, _lodash.isEmpty)(image) || hasError) && typeof name === 'string') {
    const [firstName, secondOrLastName] = useFirstLetter ? [name.substr(0, 1), ''] : type === _Avatar.AvatarType.User ? name.split(' ') : name.substr(0, 2);
    const text = "".concat(firstName.substr(0, 1).toUpperCase()).concat(secondOrLastName !== 'undefined' && (secondOrLastName === null || secondOrLastName === void 0 ? void 0 : secondOrLastName.substr(0, 1).toUpperCase()));
    return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: (0, _styles.apply)((0, _styles.classNames)('itemsCenter justifyCenter', {
        'h8 w8 radius2': size === _Avatar.AvatarSize.Tiny,
        'h10 w10 radius2': size === _Avatar.AvatarSize.Small,
        'h12 w12 radius2': size === _Avatar.AvatarSize.Medium,
        'h16 w16 radius2': size === _Avatar.AvatarSize.Large,
        'h8 w8 radius4': size === _Avatar.AvatarSize.Tiny && shape === _Avatar.AvatarShape.Circle,
        'h10 w10 radius5': size === _Avatar.AvatarSize.Small && shape === _Avatar.AvatarShape.Circle,
        'h12 w12 radius6': size === _Avatar.AvatarSize.Medium && shape === _Avatar.AvatarShape.Circle,
        'h16 w16 radius8': size === _Avatar.AvatarSize.Large && shape === _Avatar.AvatarShape.Circle
      }), {
        backgroundColor: color
      }, style)
    }, /*#__PURE__*/_react.default.createElement(_Text.default, _extends({}, textProps, {
      color: _Colors.TextColor.white,
      align: _Text.TextAlign.Center
    }), text));
  }

  return /*#__PURE__*/_react.default.createElement(_reactNativeFastImage.default, {
    resizeMode: "contain",
    style: (0, _styles.apply)((0, _styles.classNames)('itemsCenter justifyCenter', {
      'h8 w8 radius2': size === _Avatar.AvatarSize.Tiny,
      'h10 w10 radius2': size === _Avatar.AvatarSize.Small,
      'h12 w12 radius2': size === _Avatar.AvatarSize.Medium,
      'h24 w24 radius2': size === _Avatar.AvatarSize.Large,
      'h8 w8 radius4': size === _Avatar.AvatarSize.Tiny && shape === _Avatar.AvatarShape.Circle,
      'h10 w10 radius5': size === _Avatar.AvatarSize.Small && shape === _Avatar.AvatarShape.Circle,
      'h12 w12 radius6': size === _Avatar.AvatarSize.Medium && shape === _Avatar.AvatarShape.Circle,
      'h16 w16 radius8': size === _Avatar.AvatarSize.Large && shape === _Avatar.AvatarShape.Circle
    }), style),
    onError: handleError,
    source: source
  });
};

var _default = Avatar;
exports.default = _default;
//# sourceMappingURL=Avatar.js.map