"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _reactNative = require("react-native");

var _react = _interopRequireWildcard(require("react"));

var _Text = _interopRequireWildcard(require("./../Text"));

var _Button = require("./Button.types");

var _styles = require("../../styles");

var _Colors = _interopRequireWildcard(require("../../Colors"));

var _Icon = require("../Icon");

var _AwesomeIcon = _interopRequireWildcard(require("../AwesomeIcon"));

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

const Button = ({
  disabled,
  iconName,
  iconVariant = _AwesomeIcon.AwesomeIconVariant.Regular,
  onPress,
  provider,
  size = _Button.ButtonSize.Medium,
  testID,
  text,
  uppercase = false,
  variant = _Button.ButtonVariant.Primary
}, ref) => {
  const handlePress = event => {
    if (!disabled) {
      onPress(event);
    }
  };

  const textProps = (0, _react.useMemo)(() => {
    switch (size) {
      case _Button.ButtonSize.Small:
        return {
          variant: _Text.TextVariant.ExtraExtraSmall
        };

      case _Button.ButtonSize.Medium:
      case _Button.ButtonSize.Large:
      default:
        return {
          variant: _Text.TextVariant.Small,
          weight: _Text.FontWeight.Bold
        };
    }
  }, [size]);

  const renderSocialIcon = () => {
    if (variant !== _Button.ButtonVariant.Social) {
      return null;
    }

    if (provider === _Button.SocialButton.Apple) {
      return /*#__PURE__*/_react.default.createElement(_Icon.AppleLogo, {
        style: _styles.C.mr2
      });
    }

    return /*#__PURE__*/_react.default.createElement(_Icon.GoogleLogo, {
      style: _styles.C.mr2
    });
  };

  const renderIcon = () => {
    if (!iconName) {
      return null;
    }

    return /*#__PURE__*/_react.default.createElement(_AwesomeIcon.default, {
      icon: iconName,
      style: _styles.C.mr2,
      variant: iconVariant,
      size: _AwesomeIcon.AwesomeIconSize.Medium,
      color: _Button.ButtonVariant.Primary ? _Colors.default.white : _Colors.default.squidInk
    });
  };

  return /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, _extends({
    style: (0, _styles.classNames)('row justifyCenter px2 wFull itemsCenter', {
      'bgAction': variant === _Button.ButtonVariant.Primary,
      'bgDisrupt': variant === _Button.ButtonVariant.Secondary,
      'bgWhite': variant === _Button.ButtonVariant.Social,
      'h5 radius1': size === _Button.ButtonSize.Small,
      'h11 radius2': size === _Button.ButtonSize.Medium,
      'h13 radius2': size === _Button.ButtonSize.Large,
      'opacity50': disabled,
      uppercase
    }),
    ref: ref,
    onPress: handlePress
  }, {
    testID
  }), renderSocialIcon(), renderIcon(), /*#__PURE__*/_react.default.createElement(_Text.default, _extends({
    color: variant === _Button.ButtonVariant.Social ? _Colors.TextColor.squidInk : _Colors.TextColor.white
  }, textProps, {
    numberOfLines: 1
  }), text || ''));
};

var _default = /*#__PURE__*/(0, _react.forwardRef)(Button);

exports.default = _default;
//# sourceMappingURL=Button.js.map