"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _reactNative = require("react-native");

var _styles = require("../../styles");

var _Colors = _interopRequireDefault(require("../../Colors"));

var _Input = require("./Input.types");

var _AwesomeIcon = _interopRequireWildcard(require("../AwesomeIcon"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

const LABEL_FROM_TRANSLATE_Y = 0;
const LABEL_TO_TRANSLATE_Y = -10;
const LABEL_FROM_FONT_SIZE = 16;
const LABEL_TO_FONT_SIZE = 12;
const LABEL_FROM_LETTER_SPACING = 0.4;
const LABEL_TO_LETTER_SPACING = 0.25;
const ANIMATED_LABEL_DURATION = 400;

const AnimatedLabel = ({
  children,
  error,
  placeholderToLabel,
  style
}) => {
  const translateY = (0, _react.useRef)(new _reactNative.Animated.Value(LABEL_FROM_TRANSLATE_Y)).current;
  const fontSize = (0, _react.useRef)(new _reactNative.Animated.Value(LABEL_FROM_FONT_SIZE)).current;
  const letterSpacing = (0, _react.useRef)(new _reactNative.Animated.Value(LABEL_FROM_LETTER_SPACING)).current;
  (0, _react.useEffect)(() => {
    if (placeholderToLabel) {
      _reactNative.Animated.parallel([_reactNative.Animated.timing(translateY, {
        toValue: LABEL_TO_TRANSLATE_Y,
        duration: ANIMATED_LABEL_DURATION,
        useNativeDriver: false
      }), _reactNative.Animated.timing(fontSize, {
        toValue: LABEL_TO_FONT_SIZE,
        duration: ANIMATED_LABEL_DURATION,
        useNativeDriver: false
      }), _reactNative.Animated.timing(letterSpacing, {
        toValue: LABEL_TO_LETTER_SPACING,
        duration: ANIMATED_LABEL_DURATION,
        useNativeDriver: false
      })]).start();
    } else {
      _reactNative.Animated.parallel([_reactNative.Animated.timing(translateY, {
        toValue: LABEL_FROM_TRANSLATE_Y,
        duration: ANIMATED_LABEL_DURATION,
        useNativeDriver: false
      }), _reactNative.Animated.timing(fontSize, {
        toValue: LABEL_FROM_FONT_SIZE,
        duration: ANIMATED_LABEL_DURATION,
        useNativeDriver: false
      }), _reactNative.Animated.timing(letterSpacing, {
        toValue: LABEL_FROM_LETTER_SPACING,
        duration: ANIMATED_LABEL_DURATION,
        useNativeDriver: false
      })]).start();
    }
  }, [placeholderToLabel, translateY, fontSize, letterSpacing]);
  return /*#__PURE__*/_react.default.createElement(_reactNative.Animated.Text, {
    style: (0, _styles.apply)((0, _styles.classNames)('absolute wFull justifyCenter', {
      textNeutral: !error,
      textWarning: error
    }), // @ts-ignore
    {
      transform: [{
        translateY
      }],
      fontSize,
      letterSpacing,
      style
    })
  }, children || '');
};

const Input = ({
  autoCapitalize = 'none',
  cancelAnimation = false,
  containerStyle,
  disabled,
  error = false,
  focused = false,
  icon,
  inputStyle,
  onBlur,
  onChange,
  onFocus,
  placeholder,
  placeholderToLabel,
  readonly,
  required,
  secureTextEntry,
  showResetButton = false,
  size = _Input.InputSize.Medium,
  // eslint-disable-next-line @typescript-eslint/no-unused-vars
  style,
  ...props
}, ref) => {
  const valueRef = (0, _react.useRef)(props.defaultValue || '');
  const inputRef = (0, _react.useRef)(null);
  const [value, setValue] = (0, _react.useState)(props.defaultValue || '');
  const [isFocused, setIsFocused] = (0, _react.useState)(focused);
  const [isSecure, setIsSecure] = (0, _react.useState)(secureTextEntry !== null && secureTextEntry !== void 0 ? secureTextEntry : false);
  const [showReset, setShowReset] = (0, _react.useState)(false);
  (0, _react.useEffect)(() => {
    setIsFocused(focused);
  }, [focused]);
  (0, _react.useImperativeHandle)(ref, () => ({
    getValue: () => valueRef.current,
    setValue: val => valueRef.current = val
  }), []);

  const handleChange = e => {
    valueRef.current = e.nativeEvent.text;
    setValue(e.nativeEvent.text);
    onChange === null || onChange === void 0 ? void 0 : onChange(e.nativeEvent.text);
    setShowReset(valueRef.current !== '');
  };

  const handleFocus = e => {
    setIsFocused(true);
    onFocus === null || onFocus === void 0 ? void 0 : onFocus(e);
  };

  const handleBlur = e => {
    setIsFocused(false);
    onBlur === null || onBlur === void 0 ? void 0 : onBlur(e);
  };

  const animatePlaceholder = (0, _react.useMemo)(() => {
    if (placeholderToLabel) {
      return placeholderToLabel(isFocused, value);
    }

    return isFocused || value.length > 0;
  }, [isFocused, placeholderToLabel, value]);

  const toggleSecure = () => setIsSecure(prev => !prev);

  const resetInput = () => {
    var _inputRef$current;

    valueRef.current = '';
    setValue('');
    onChange === null || onChange === void 0 ? void 0 : onChange('');
    setShowReset(false);
    (_inputRef$current = inputRef.current) === null || _inputRef$current === void 0 ? void 0 : _inputRef$current.clear();
  };

  return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: (0, _styles.apply)((0, _styles.classNames)('row wFull borderMinimum borderPlatin radius2 itemsCenter px4', {
      borderWarning: error,
      borderAction: isFocused,
      borderTransparent: disabled || readonly,
      h14: size === _Input.InputSize.Medium,
      h12: size === _Input.InputSize.Small,
      bgPlatin: !disabled,
      bgDisabled: disabled,
      bgReadonly: readonly
    }), containerStyle)
  }, icon && !readonly ? /*#__PURE__*/_react.default.createElement(_AwesomeIcon.default, {
    color: disabled ? _Colors.default.neutral : !isFocused && error ? _Colors.default.warning : _Colors.default.action,
    icon: !isFocused && error ? 'exclamation-triangle' : icon,
    size: _AwesomeIcon.AwesomeIconSize.ExtraSmall,
    style: _styles.C.mr4,
    variant: _AwesomeIcon.AwesomeIconVariant.Regular
  }) : null, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: (0, _styles.apply)(_styles.C.hFull, _styles.C.justifyCenter, _styles.C.flex)
  }, /*#__PURE__*/_react.default.createElement(AnimatedLabel, {
    error: !isFocused && error,
    placeholderToLabel: !disabled && !cancelAnimation && animatePlaceholder
  }, "".concat(placeholder, " ").concat(required ? '*' : '')), (disabled || readonly) && /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: (0, _styles.apply)(_styles.C.hFull, _styles.C.wFull, _styles.C.absolute, {
      zIndex: 2
    })
  }), /*#__PURE__*/_react.default.createElement(_reactNative.TextInput, _extends({
    autoCapitalize: autoCapitalize,
    defaultValue: valueRef.current,
    editable: disabled,
    onBlur: handleBlur,
    onChange: handleChange,
    onFocus: handleFocus,
    ref: inputRef,
    secureTextEntry: secureTextEntry && isSecure,
    style: (0, _styles.apply)(_styles.C.hFull, _styles.C.flex, _styles.C.font4, _styles.C.p0, _styles.C.pt4, _styles.C.textSquidInk, inputStyle),
    underlineColorAndroid: _Colors.default.transparent
  }, props))), showReset && showResetButton ? /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
    activeOpacity: 0.8,
    onPress: resetInput
  }, /*#__PURE__*/_react.default.createElement(_AwesomeIcon.default, {
    color: _Colors.default.neutral,
    icon: "times",
    size: _AwesomeIcon.AwesomeIconSize.ExtraSmall,
    style: _styles.C.ml2,
    variant: _AwesomeIcon.AwesomeIconVariant.Light
  })) : null, secureTextEntry ? /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
    activeOpacity: 0.8,
    onPress: toggleSecure
  }, /*#__PURE__*/_react.default.createElement(_AwesomeIcon.default, {
    color: _Colors.default.action,
    icon: isSecure ? 'eye' : 'eye-slash',
    size: _AwesomeIcon.AwesomeIconSize.ExtraSmall,
    style: _styles.C.ml2,
    variant: _AwesomeIcon.AwesomeIconVariant.Regular
  })) : null);
};

var _default = /*#__PURE__*/(0, _react.forwardRef)(Input);

exports.default = _default;
//# sourceMappingURL=Input.js.map