"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _reactNative = require("react-native");

var _reactNativePickerSelect = _interopRequireDefault(require("react-native-picker-select"));

var _Colors = _interopRequireDefault(require("../../Colors"));

var _styles = require("../../styles");

var _AwesomeIcon = _interopRequireWildcard(require("../AwesomeIcon"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const Select = ({
  containerStyle,
  disabled = false,
  error = false,
  focused = false,
  icon,
  inputStyle,
  items,
  label,
  onChange,
  placeholder,
  readonly = false,
  value
}, ref) => {
  const [currentValue, setCurrentValue] = (0, _react.useState)(value || null);
  const selectRef = (0, _react.useRef)(null);
  const [isFocused, setIsFocused] = (0, _react.useState)(focused);

  const handleChange = val => {
    setCurrentValue(val);
    onChange === null || onChange === void 0 ? void 0 : onChange(val);
    setIsFocused(false);
  };

  (0, _react.useImperativeHandle)(ref, () => ({
    getValue: () => currentValue,
    setValue: val => setCurrentValue(val)
  }), [currentValue]);

  const handleOpen = () => {
    if (_reactNative.Platform.OS === 'ios') {
      setIsFocused(true);
    }
  };

  const handleClose = () => {
    if (_reactNative.Platform.OS === 'ios') {
      setIsFocused(false);
    }
  };

  const canInteract = (0, _react.useMemo)(() => !disabled && !readonly, [disabled, readonly]);

  const handlePress = () => {
    if (canInteract) {
      var _selectRef$current;

      (_selectRef$current = selectRef.current) === null || _selectRef$current === void 0 ? void 0 : _selectRef$current.togglePicker();
    }
  };

  const innerPlaceholder = (0, _react.useMemo)(() => ({
    label: placeholder !== null && placeholder !== void 0 ? placeholder : label,
    value: null
  }) || null, [placeholder, label]);
  (0, _react.useEffect)(() => {
    setIsFocused(focused);
  }, [focused]);
  (0, _react.useEffect)(() => {
    setCurrentValue(value !== null && value !== void 0 ? value : null);
  }, [value]);
  return /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
    activeOpacity: 1,
    onPress: handlePress,
    style: (0, _styles.apply)((0, _styles.classNames)('row wFull h14 borderMinimum borderPlatin radius2 itemsCenter px4', {
      borderWarning: error,
      borderAction: isFocused,
      borderTransparent: disabled || readonly,
      bgPlatin: !disabled,
      bgDisabled: disabled,
      bgReadonly: readonly
    }), containerStyle)
  }, icon && !readonly ? /*#__PURE__*/_react.default.createElement(_AwesomeIcon.default, {
    color: disabled ? _Colors.default.neutral : !isFocused && error ? _Colors.default.warning : _Colors.default.action,
    icon: !isFocused && error ? 'exclamation-triangle' : icon,
    size: _AwesomeIcon.AwesomeIconSize.ExtraSmall,
    style: _styles.C.mr4,
    variant: _AwesomeIcon.AwesomeIconVariant.Regular
  }) : null, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: (0, _styles.apply)(_styles.C.hFull, _styles.C.justifyCenter, _styles.C.flex)
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: (0, _styles.apply)((0, _styles.classNames)('absolute wFull justifyCenter top2', {
      textWarning: !isFocused && error,
      textAction: isFocused,
      textNeutral: !error
    }), {
      fontSize: 12
    })
  }, label || placeholder), /*#__PURE__*/_react.default.createElement(_reactNativePickerSelect.default, {
    disabled: !canInteract,
    onValueChange: handleChange,
    onOpen: handleOpen,
    onClose: handleClose,
    items: items,
    touchableWrapperProps: {
      style: (0, _styles.classNames)('hFull justifyCenter pt4', {})
    },
    useNativeAndroidPickerStyle: false,
    textInputProps: {
      // @ts-ignore
      style: (0, _styles.apply)((0, _styles.classNames)('font4 hFull p0 textSquidInk'), inputStyle)
    },
    ref: selectRef,
    Icon: () => null,
    fixAndroidTouchableBug: true,
    placeholder: innerPlaceholder,
    value: currentValue
  })), canInteract ? /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
    onPress: handlePress
  }, /*#__PURE__*/_react.default.createElement(_AwesomeIcon.default, {
    color: _Colors.default.action,
    icon: "chevron-down",
    size: _AwesomeIcon.AwesomeIconSize.ExtraSmall,
    style: _styles.C.ml2,
    variant: _AwesomeIcon.AwesomeIconVariant.Regular
  })) : null);
};

var _default = /*#__PURE__*/(0, _react.forwardRef)(Select);

exports.default = _default;
//# sourceMappingURL=Select.js.map