import React, { forwardRef, useEffect, useImperativeHandle, useState } from 'react';
import { TouchableOpacity, View } from 'react-native';
import RNModal from 'react-native-modal';
import { SafeAreaView } from 'react-native-safe-area-context';
import AwesomeIcon, { AwesomeIconVariant, AwesomeIconSize } from '../AwesomeIcon';
import { C, apply, classNames } from '../../styles';
import Color, { TextColor } from '../../Colors';
import Text, { TextVariant, FontWeight } from '../Text';

const ActionSheet = ({
  closeText,
  items,
  title,
  visible = false
}, ref) => {
  const [isVisible, setIsVisible] = useState(visible);

  const close = () => setIsVisible(false);

  const open = () => setIsVisible(true);

  useImperativeHandle(ref, () => ({
    open,
    close
  }), []);
  useEffect(() => {
    setIsVisible(visible);
  }, [visible]);

  const handlePress = item => () => {
    if (!item.disabled && item.onPress) {
      item.onPress();
    }
  };

  const hasIcon = items.some(item => item.icon);
  return /*#__PURE__*/React.createElement(RNModal, {
    isVisible: isVisible,
    useNativeDriver: true,
    hideModalContentWhileAnimating: true,
    onBackButtonPress: close,
    onBackdropPress: close,
    style: apply(C.m0, C.px2, C.flex, C.justifyEnd)
  }, /*#__PURE__*/React.createElement(SafeAreaView, {
    style: C.pb4
  }, /*#__PURE__*/React.createElement(View, {
    style: apply(C.bgBackdrop, C.radius3)
  }, title ? /*#__PURE__*/React.createElement(View, {
    style: apply(C.h10, C.itemsCenter, C.justifyCenter)
  }, /*#__PURE__*/React.createElement(Text, {
    variant: TextVariant.XS,
    color: TextColor.support
  }, title)) : null, items === null || items === void 0 ? void 0 : items.map((item, index) => /*#__PURE__*/React.createElement(TouchableOpacity, {
    activeOpacity: item.onPress ? 0.8 : 1,
    onPress: handlePress(item),
    key: index,
    style: classNames('h14 row px4 itemsCenter bordertopHairline bordertopSupport', {
      justifyCenter: !hasIcon,
      justifyBetween: hasIcon
    })
  }, /*#__PURE__*/React.createElement(Text, {
    variant: TextVariant.S,
    weight: FontWeight.Regular,
    color: TextColor.action
  }, item.label), item.icon ? /*#__PURE__*/React.createElement(AwesomeIcon, {
    style: C.ml2,
    variant: AwesomeIconVariant.Solid,
    size: AwesomeIconSize.Medium,
    color: Color.action,
    icon: item.icon
  }) : null))), /*#__PURE__*/React.createElement(TouchableOpacity, {
    onPress: close,
    activeOpacity: 0.8,
    style: apply(C.mt3, C.py4, C.bgWhite, C.radius3, C.itemsCenter)
  }, /*#__PURE__*/React.createElement(Text, {
    variant: TextVariant.S,
    weight: FontWeight.Bold,
    color: TextColor.action
  }, closeText))));
};

export default /*#__PURE__*/forwardRef(ActionSheet);
//# sourceMappingURL=ActionSheet.js.map