function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import { isEmpty } from 'lodash';
import React, { useMemo, useState } from 'react';
import { View } from 'react-native';
import FastImage from 'react-native-fast-image';
import { AvatarShape, AvatarSize, AvatarType } from './Avatar.types';
import { apply, classNames } from '../../styles';
import Color, { TextColor } from '../../Colors';
import Images from '../../Images';
import Text, { TextVariant, FontWeight, TextAlign } from '../Text';

const Avatar = ({
  color = Color.iconic,
  image = null,
  name,
  shape = AvatarShape.RoundedSquare,
  size = AvatarSize.Tiny,
  style,
  type = AvatarType.User,
  useFirstLetter = false
}) => {
  const [hasError, setHasError] = useState(false);
  const source = useMemo(() => image && !isEmpty(image) && !hasError ? {
    uri: image
  } : Images.HOLDED_LOGO, [image, hasError]);

  const handleError = () => setHasError(true);

  const textProps = useMemo(() => {
    switch (size) {
      case AvatarSize.Tiny:
      case AvatarSize.Small:
      default:
        return {
          variant: TextVariant.ExtraSmall
        };

      case AvatarSize.Medium:
        return {
          variant: TextVariant.Small,
          weight: FontWeight.Bold
        };

      case AvatarSize.Large:
        return {
          variant: TextVariant.Large,
          weight: FontWeight.Bold
        };
    }
  }, [size]);

  if ((isEmpty(image) || hasError) && typeof name === 'string') {
    const [firstName, secondOrLastName] = useFirstLetter ? [name.substr(0, 1), ''] : type === AvatarType.User ? name.split(' ') : name.substr(0, 2);
    const text = "".concat(firstName.substr(0, 1).toUpperCase()).concat(secondOrLastName !== 'undefined' && (secondOrLastName === null || secondOrLastName === void 0 ? void 0 : secondOrLastName.substr(0, 1).toUpperCase()));
    return /*#__PURE__*/React.createElement(View, {
      style: apply(classNames('itemsCenter justifyCenter', {
        'h8 w8 radius2': size === AvatarSize.Tiny,
        'h10 w10 radius2': size === AvatarSize.Small,
        'h12 w12 radius2': size === AvatarSize.Medium,
        'h16 w16 radius2': size === AvatarSize.Large,
        'h8 w8 radius4': size === AvatarSize.Tiny && shape === AvatarShape.Circle,
        'h10 w10 radius5': size === AvatarSize.Small && shape === AvatarShape.Circle,
        'h12 w12 radius6': size === AvatarSize.Medium && shape === AvatarShape.Circle,
        'h16 w16 radius8': size === AvatarSize.Large && shape === AvatarShape.Circle
      }), {
        backgroundColor: color
      }, style)
    }, /*#__PURE__*/React.createElement(Text, _extends({}, textProps, {
      color: TextColor.white,
      align: TextAlign.Center
    }), text));
  }

  return /*#__PURE__*/React.createElement(FastImage, {
    resizeMode: "contain",
    style: apply(classNames('itemsCenter justifyCenter', {
      'h8 w8 radius2': size === AvatarSize.Tiny,
      'h10 w10 radius2': size === AvatarSize.Small,
      'h12 w12 radius2': size === AvatarSize.Medium,
      'h24 w24 radius2': size === AvatarSize.Large,
      'h8 w8 radius4': size === AvatarSize.Tiny && shape === AvatarShape.Circle,
      'h10 w10 radius5': size === AvatarSize.Small && shape === AvatarShape.Circle,
      'h12 w12 radius6': size === AvatarSize.Medium && shape === AvatarShape.Circle,
      'h16 w16 radius8': size === AvatarSize.Large && shape === AvatarShape.Circle
    }), style),
    onError: handleError,
    source: source
  });
};

export default Avatar;
//# sourceMappingURL=Avatar.js.map