function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import { TouchableOpacity } from 'react-native';
import React, { useMemo, forwardRef } from 'react';
import Text, { FontWeight, TextVariant } from './../Text';
import { ButtonVariant, ButtonSize } from './Button.types';
import { classNames, C } from '../../styles';
import Color, { TextColor } from '../../Colors';
import { SocialButton } from './Button.types';
import { AppleLogo, GoogleLogo } from '../Icon';
import AwesomeIcon, { AwesomeIconSize, AwesomeIconVariant } from '../AwesomeIcon';

const Button = ({
  disabled,
  iconName,
  iconVariant = AwesomeIconVariant.Regular,
  onPress,
  provider,
  size = ButtonSize.Medium,
  testID,
  text,
  uppercase = false,
  variant = ButtonVariant.Primary
}, ref) => {
  const handlePress = event => {
    if (!disabled) {
      onPress(event);
    }
  };

  const textProps = useMemo(() => {
    switch (size) {
      case ButtonSize.Small:
        return {
          variant: TextVariant.ExtraExtraSmall
        };

      case ButtonSize.Medium:
      case ButtonSize.Large:
      default:
        return {
          variant: TextVariant.Small,
          weight: FontWeight.Bold
        };
    }
  }, [size]);

  const renderSocialIcon = () => {
    if (variant !== ButtonVariant.Social) {
      return null;
    }

    if (provider === SocialButton.Apple) {
      return /*#__PURE__*/React.createElement(AppleLogo, {
        style: C.mr2
      });
    }

    return /*#__PURE__*/React.createElement(GoogleLogo, {
      style: C.mr2
    });
  };

  const renderIcon = () => {
    if (!iconName) {
      return null;
    }

    return /*#__PURE__*/React.createElement(AwesomeIcon, {
      icon: iconName,
      style: C.mr2,
      variant: iconVariant,
      size: AwesomeIconSize.Medium,
      color: ButtonVariant.Primary ? Color.white : Color.squidInk
    });
  };

  return /*#__PURE__*/React.createElement(TouchableOpacity, _extends({
    style: classNames('row justifyCenter px2 wFull itemsCenter', {
      'bgAction': variant === ButtonVariant.Primary,
      'bgDisrupt': variant === ButtonVariant.Secondary,
      'bgWhite': variant === ButtonVariant.Social,
      'h5 radius1': size === ButtonSize.Small,
      'h11 radius2': size === ButtonSize.Medium,
      'h13 radius2': size === ButtonSize.Large,
      'opacity50': disabled,
      uppercase
    }),
    ref: ref,
    onPress: handlePress
  }, {
    testID
  }), renderSocialIcon(), renderIcon(), /*#__PURE__*/React.createElement(Text, _extends({
    color: variant === ButtonVariant.Social ? TextColor.squidInk : TextColor.white
  }, textProps, {
    numberOfLines: 1
  }), text || ''));
};

export default /*#__PURE__*/forwardRef(Button);
//# sourceMappingURL=Button.js.map