function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React, { forwardRef, useEffect, useImperativeHandle, useMemo, useRef, useState } from 'react';
import { View, TextInput, TouchableOpacity, Animated } from 'react-native';
import { apply, C, classNames } from '../../styles';
import Color from '../../Colors';
import { InputSize } from './Input.types';
import AwesomeIcon, { AwesomeIconSize, AwesomeIconVariant } from '../AwesomeIcon';
const LABEL_FROM_TRANSLATE_Y = 0;
const LABEL_TO_TRANSLATE_Y = -10;
const LABEL_FROM_FONT_SIZE = 16;
const LABEL_TO_FONT_SIZE = 12;
const LABEL_FROM_LETTER_SPACING = 0.4;
const LABEL_TO_LETTER_SPACING = 0.25;
const ANIMATED_LABEL_DURATION = 400;

const AnimatedLabel = ({
  children,
  error,
  placeholderToLabel,
  style
}) => {
  const translateY = useRef(new Animated.Value(LABEL_FROM_TRANSLATE_Y)).current;
  const fontSize = useRef(new Animated.Value(LABEL_FROM_FONT_SIZE)).current;
  const letterSpacing = useRef(new Animated.Value(LABEL_FROM_LETTER_SPACING)).current;
  useEffect(() => {
    if (placeholderToLabel) {
      Animated.parallel([Animated.timing(translateY, {
        toValue: LABEL_TO_TRANSLATE_Y,
        duration: ANIMATED_LABEL_DURATION,
        useNativeDriver: false
      }), Animated.timing(fontSize, {
        toValue: LABEL_TO_FONT_SIZE,
        duration: ANIMATED_LABEL_DURATION,
        useNativeDriver: false
      }), Animated.timing(letterSpacing, {
        toValue: LABEL_TO_LETTER_SPACING,
        duration: ANIMATED_LABEL_DURATION,
        useNativeDriver: false
      })]).start();
    } else {
      Animated.parallel([Animated.timing(translateY, {
        toValue: LABEL_FROM_TRANSLATE_Y,
        duration: ANIMATED_LABEL_DURATION,
        useNativeDriver: false
      }), Animated.timing(fontSize, {
        toValue: LABEL_FROM_FONT_SIZE,
        duration: ANIMATED_LABEL_DURATION,
        useNativeDriver: false
      }), Animated.timing(letterSpacing, {
        toValue: LABEL_FROM_LETTER_SPACING,
        duration: ANIMATED_LABEL_DURATION,
        useNativeDriver: false
      })]).start();
    }
  }, [placeholderToLabel, translateY, fontSize, letterSpacing]);
  return /*#__PURE__*/React.createElement(Animated.Text, {
    style: apply(classNames('absolute wFull justifyCenter', {
      textNeutral: !error,
      textWarning: error
    }), // @ts-ignore
    {
      transform: [{
        translateY
      }],
      fontSize,
      letterSpacing,
      style
    })
  }, children || '');
};

const Input = ({
  autoCapitalize = 'none',
  cancelAnimation = false,
  containerStyle,
  disabled,
  error = false,
  focused = false,
  icon,
  inputStyle,
  onBlur,
  onChange,
  onFocus,
  placeholder,
  placeholderToLabel,
  readonly,
  required,
  secureTextEntry,
  showResetButton = false,
  size = InputSize.Medium,
  // eslint-disable-next-line @typescript-eslint/no-unused-vars
  style,
  ...props
}, ref) => {
  const valueRef = useRef(props.defaultValue || '');
  const inputRef = useRef(null);
  const [value, setValue] = useState(props.defaultValue || '');
  const [isFocused, setIsFocused] = useState(focused);
  const [isSecure, setIsSecure] = useState(secureTextEntry !== null && secureTextEntry !== void 0 ? secureTextEntry : false);
  const [showReset, setShowReset] = useState(false);
  useEffect(() => {
    setIsFocused(focused);
  }, [focused]);
  useImperativeHandle(ref, () => ({
    getValue: () => valueRef.current,
    setValue: val => valueRef.current = val
  }), []);

  const handleChange = e => {
    valueRef.current = e.nativeEvent.text;
    setValue(e.nativeEvent.text);
    onChange === null || onChange === void 0 ? void 0 : onChange(e.nativeEvent.text);
    setShowReset(valueRef.current !== '');
  };

  const handleFocus = e => {
    setIsFocused(true);
    onFocus === null || onFocus === void 0 ? void 0 : onFocus(e);
  };

  const handleBlur = e => {
    setIsFocused(false);
    onBlur === null || onBlur === void 0 ? void 0 : onBlur(e);
  };

  const animatePlaceholder = useMemo(() => {
    if (placeholderToLabel) {
      return placeholderToLabel(isFocused, value);
    }

    return isFocused || value.length > 0;
  }, [isFocused, placeholderToLabel, value]);

  const toggleSecure = () => setIsSecure(prev => !prev);

  const resetInput = () => {
    var _inputRef$current;

    valueRef.current = '';
    setValue('');
    onChange === null || onChange === void 0 ? void 0 : onChange('');
    setShowReset(false);
    (_inputRef$current = inputRef.current) === null || _inputRef$current === void 0 ? void 0 : _inputRef$current.clear();
  };

  return /*#__PURE__*/React.createElement(View, {
    style: apply(classNames('row wFull borderMinimum borderPlatin radius2 itemsCenter px4', {
      borderWarning: error,
      borderAction: isFocused,
      borderTransparent: disabled || readonly,
      h14: size === InputSize.Medium,
      h12: size === InputSize.Small,
      bgPlatin: !disabled,
      bgDisabled: disabled,
      bgReadonly: readonly
    }), containerStyle)
  }, icon && !readonly ? /*#__PURE__*/React.createElement(AwesomeIcon, {
    color: disabled ? Color.neutral : !isFocused && error ? Color.warning : Color.action,
    icon: !isFocused && error ? 'exclamation-triangle' : icon,
    size: AwesomeIconSize.ExtraSmall,
    style: C.mr4,
    variant: AwesomeIconVariant.Regular
  }) : null, /*#__PURE__*/React.createElement(View, {
    style: apply(C.hFull, C.justifyCenter, C.flex)
  }, /*#__PURE__*/React.createElement(AnimatedLabel, {
    error: !isFocused && error,
    placeholderToLabel: !disabled && !cancelAnimation && animatePlaceholder
  }, "".concat(placeholder, " ").concat(required ? '*' : '')), (disabled || readonly) && /*#__PURE__*/React.createElement(View, {
    style: apply(C.hFull, C.wFull, C.absolute, {
      zIndex: 2
    })
  }), /*#__PURE__*/React.createElement(TextInput, _extends({
    autoCapitalize: autoCapitalize,
    defaultValue: valueRef.current,
    editable: disabled,
    onBlur: handleBlur,
    onChange: handleChange,
    onFocus: handleFocus,
    ref: inputRef,
    secureTextEntry: secureTextEntry && isSecure,
    style: apply(C.hFull, C.flex, C.font4, C.p0, C.pt4, C.textSquidInk, inputStyle),
    underlineColorAndroid: Color.transparent
  }, props))), showReset && showResetButton ? /*#__PURE__*/React.createElement(TouchableOpacity, {
    activeOpacity: 0.8,
    onPress: resetInput
  }, /*#__PURE__*/React.createElement(AwesomeIcon, {
    color: Color.neutral,
    icon: "times",
    size: AwesomeIconSize.ExtraSmall,
    style: C.ml2,
    variant: AwesomeIconVariant.Light
  })) : null, secureTextEntry ? /*#__PURE__*/React.createElement(TouchableOpacity, {
    activeOpacity: 0.8,
    onPress: toggleSecure
  }, /*#__PURE__*/React.createElement(AwesomeIcon, {
    color: Color.action,
    icon: isSecure ? 'eye' : 'eye-slash',
    size: AwesomeIconSize.ExtraSmall,
    style: C.ml2,
    variant: AwesomeIconVariant.Regular
  })) : null);
};

export default /*#__PURE__*/forwardRef(Input);
//# sourceMappingURL=Input.js.map