import React, { useRef, useEffect, forwardRef, useImperativeHandle, useState } from 'react';
import { apply, C } from '../../styles';
import { Animated, Easing, View } from 'react-native';
const LOADER_HEIGHT = 60;

const Loader = ({
  loading = false
}, ref) => {
  const barInnerHeightAnim = useRef(new Animated.Value(LOADER_HEIGHT)).current;
  const barMiddleHeightAnim = useRef(new Animated.Value(LOADER_HEIGHT * 0.6)).current;
  const barOuterHeightAnim = useRef(new Animated.Value(LOADER_HEIGHT * 0.3)).current;
  const [isLoading, setIsLoading] = useState(loading);

  const show = () => setIsLoading(true);

  const hide = () => setIsLoading(false);

  useEffect(() => {
    setIsLoading(loading);
  }, [loading]);
  useImperativeHandle(ref, () => ({
    show,
    hide
  }), []);
  useEffect(() => {
    if (isLoading) {
      Animated.loop(Animated.sequence([Animated.parallel([Animated.timing(barInnerHeightAnim, {
        toValue: LOADER_HEIGHT * 0.6,
        duration: 250,
        useNativeDriver: false,
        easing: Easing.out(Easing.ease)
      }), Animated.timing(barMiddleHeightAnim, {
        toValue: LOADER_HEIGHT * 0.3,
        duration: 250,
        useNativeDriver: false,
        easing: Easing.out(Easing.ease)
      }), Animated.timing(barOuterHeightAnim, {
        toValue: LOADER_HEIGHT * 0.6,
        duration: 250,
        useNativeDriver: false,
        easing: Easing.out(Easing.ease)
      })]), Animated.parallel([Animated.timing(barInnerHeightAnim, {
        toValue: LOADER_HEIGHT * 0.3,
        duration: 250,
        useNativeDriver: false,
        easing: Easing.out(Easing.ease)
      }), Animated.timing(barMiddleHeightAnim, {
        toValue: LOADER_HEIGHT * 0.6,
        duration: 250,
        useNativeDriver: false,
        easing: Easing.out(Easing.ease)
      }), Animated.timing(barOuterHeightAnim, {
        toValue: LOADER_HEIGHT,
        duration: 250,
        useNativeDriver: false,
        easing: Easing.out(Easing.ease)
      })]), Animated.parallel([Animated.timing(barInnerHeightAnim, {
        toValue: LOADER_HEIGHT * 0.6,
        duration: 250,
        useNativeDriver: false,
        easing: Easing.out(Easing.ease)
      }), Animated.timing(barMiddleHeightAnim, {
        toValue: LOADER_HEIGHT,
        duration: 250,
        useNativeDriver: false,
        easing: Easing.out(Easing.ease)
      }), Animated.timing(barOuterHeightAnim, {
        toValue: LOADER_HEIGHT * 0.6,
        duration: 250,
        useNativeDriver: false,
        easing: Easing.out(Easing.ease)
      })]), Animated.parallel([Animated.timing(barInnerHeightAnim, {
        toValue: LOADER_HEIGHT,
        duration: 250,
        useNativeDriver: false,
        easing: Easing.out(Easing.ease)
      }), Animated.timing(barMiddleHeightAnim, {
        toValue: LOADER_HEIGHT * 0.6,
        duration: 250,
        useNativeDriver: false,
        easing: Easing.out(Easing.ease)
      }), Animated.timing(barOuterHeightAnim, {
        toValue: LOADER_HEIGHT * 0.3,
        duration: 250,
        useNativeDriver: false,
        easing: Easing.out(Easing.ease)
      })])])).start();
    }
  }, [isLoading, barOuterHeightAnim, barInnerHeightAnim, barMiddleHeightAnim]);

  if (!isLoading) {
    return null;
  }

  const barStyles = apply(C.w2, C.mx1, C.bgWhite, C.radius2, {
    minHeight: LOADER_HEIGHT * 0.3,
    maxHeight: LOADER_HEIGHT
  });
  return /*#__PURE__*/React.createElement(View, {
    style: apply(C.absolute, C.wFull, C.hFull, C.bgBlack, C.opacity50, C.itemsCenter, C.justifyCenter, C.flex, {
      zIndex: 1
    })
  }, /*#__PURE__*/React.createElement(View, {
    style: apply(C.flex, C.row, C.justifyBetween, C.itemsCenter, {
      height: LOADER_HEIGHT
    })
  }, /*#__PURE__*/React.createElement(Animated.View, {
    style: apply(barStyles, {
      height: barOuterHeightAnim
    })
  }), /*#__PURE__*/React.createElement(Animated.View, {
    style: apply(barStyles, {
      height: barMiddleHeightAnim
    })
  }), /*#__PURE__*/React.createElement(Animated.View, {
    style: apply(barStyles, {
      height: barInnerHeightAnim
    })
  }), /*#__PURE__*/React.createElement(Animated.View, {
    style: apply(barStyles, {
      height: barMiddleHeightAnim
    })
  }), /*#__PURE__*/React.createElement(Animated.View, {
    style: apply(barStyles, {
      height: barOuterHeightAnim
    })
  })));
};

export default /*#__PURE__*/forwardRef(Loader);
//# sourceMappingURL=Loader.js.map