import React, { forwardRef, useEffect, useImperativeHandle, useMemo, useRef, useState } from 'react';
import { Platform, View, Text, TouchableOpacity } from 'react-native';
import RNPickerSelect from 'react-native-picker-select';
import Color from '../../Colors';
import { apply, C, classNames } from '../../styles';
import AwesomeIcon, { AwesomeIconSize, AwesomeIconVariant } from '../AwesomeIcon';

const Select = ({
  containerStyle,
  disabled = false,
  error = false,
  focused = false,
  icon,
  inputStyle,
  items,
  label,
  onChange,
  placeholder,
  readonly = false,
  value
}, ref) => {
  const [currentValue, setCurrentValue] = useState(value || null);
  const selectRef = useRef(null);
  const [isFocused, setIsFocused] = useState(focused);

  const handleChange = val => {
    setCurrentValue(val);
    onChange === null || onChange === void 0 ? void 0 : onChange(val);
    setIsFocused(false);
  };

  useImperativeHandle(ref, () => ({
    getValue: () => currentValue,
    setValue: val => setCurrentValue(val)
  }), [currentValue]);

  const handleOpen = () => {
    if (Platform.OS === 'ios') {
      setIsFocused(true);
    }
  };

  const handleClose = () => {
    if (Platform.OS === 'ios') {
      setIsFocused(false);
    }
  };

  const canInteract = useMemo(() => !disabled && !readonly, [disabled, readonly]);

  const handlePress = () => {
    if (canInteract) {
      var _selectRef$current;

      (_selectRef$current = selectRef.current) === null || _selectRef$current === void 0 ? void 0 : _selectRef$current.togglePicker();
    }
  };

  const innerPlaceholder = useMemo(() => ({
    label: placeholder !== null && placeholder !== void 0 ? placeholder : label,
    value: null
  }) || null, [placeholder, label]);
  useEffect(() => {
    setIsFocused(focused);
  }, [focused]);
  useEffect(() => {
    setCurrentValue(value !== null && value !== void 0 ? value : null);
  }, [value]);
  return /*#__PURE__*/React.createElement(TouchableOpacity, {
    activeOpacity: 1,
    onPress: handlePress,
    style: apply(classNames('row wFull h14 borderMinimum borderPlatin radius2 itemsCenter px4', {
      borderWarning: error,
      borderAction: isFocused,
      borderTransparent: disabled || readonly,
      bgPlatin: !disabled,
      bgDisabled: disabled,
      bgReadonly: readonly
    }), containerStyle)
  }, icon && !readonly ? /*#__PURE__*/React.createElement(AwesomeIcon, {
    color: disabled ? Color.neutral : !isFocused && error ? Color.warning : Color.action,
    icon: !isFocused && error ? 'exclamation-triangle' : icon,
    size: AwesomeIconSize.ExtraSmall,
    style: C.mr4,
    variant: AwesomeIconVariant.Regular
  }) : null, /*#__PURE__*/React.createElement(View, {
    style: apply(C.hFull, C.justifyCenter, C.flex)
  }, /*#__PURE__*/React.createElement(Text, {
    style: apply(classNames('absolute wFull justifyCenter top2', {
      textWarning: !isFocused && error,
      textAction: isFocused,
      textNeutral: !error
    }), {
      fontSize: 12
    })
  }, label || placeholder), /*#__PURE__*/React.createElement(RNPickerSelect, {
    disabled: !canInteract,
    onValueChange: handleChange,
    onOpen: handleOpen,
    onClose: handleClose,
    items: items,
    touchableWrapperProps: {
      style: classNames('hFull justifyCenter pt4', {})
    },
    useNativeAndroidPickerStyle: false,
    textInputProps: {
      // @ts-ignore
      style: apply(classNames('font4 hFull p0 textSquidInk'), inputStyle)
    },
    ref: selectRef,
    Icon: () => null,
    fixAndroidTouchableBug: true,
    placeholder: innerPlaceholder,
    value: currentValue
  })), canInteract ? /*#__PURE__*/React.createElement(TouchableOpacity, {
    onPress: handlePress
  }, /*#__PURE__*/React.createElement(AwesomeIcon, {
    color: Color.action,
    icon: "chevron-down",
    size: AwesomeIconSize.ExtraSmall,
    style: C.ml2,
    variant: AwesomeIconVariant.Regular
  })) : null);
};

export default /*#__PURE__*/forwardRef(Select);
//# sourceMappingURL=Select.js.map