import React, { useEffect, useRef, useState } from 'react';
import { ScrollView, TouchableOpacity, View } from 'react-native';
import { C, apply, classNames } from '../../styles';
import { TextColor } from '../../Colors';
import Text, { TextVariant } from '../Text';
// This is to scroll to more left item position in order to be able to display the previous item in order to tap it without need to scroll manually.
const SCROLL_OVERFLOW = 24;

const Tabs = ({
  containerStyle,
  data,
  justified,
  onChange,
  scrollOverflow = SCROLL_OVERFLOW,
  selected,
  tabStyle,
  tabSelectedStyle
}) => {
  const [current, setCurrent] = useState(selected || 0);
  const scrollViewRef = useRef(null);
  const elementPosition = useRef([]);

  const handlePress = (item, index) => () => {
    if (!item.disabled) {
      var _scrollViewRef$curren;

      setCurrent(index);
      onChange === null || onChange === void 0 ? void 0 : onChange(item, index);
      (_scrollViewRef$curren = scrollViewRef.current) === null || _scrollViewRef$curren === void 0 ? void 0 : _scrollViewRef$curren.scrollTo({
        x: elementPosition.current[index] - scrollOverflow
      });
    }
  };

  const setPosition = (e, index) => {
    const {
      x
    } = e.nativeEvent.layout;

    if (!elementPosition.current[index]) {
      elementPosition.current[index] = x;
    }
  };

  useEffect(() => {
    setCurrent(selected || 0);
  }, [selected]);
  return /*#__PURE__*/React.createElement(ScrollView, {
    ref: scrollViewRef,
    showsHorizontalScrollIndicator: false,
    bounces: false,
    alwaysBounceHorizontal: false,
    contentContainerStyle: classNames('', {
      wFull: justified,
      justifyBetween: justified
    }),
    horizontal: true,
    style: apply(C.row, containerStyle)
  }, data === null || data === void 0 ? void 0 : data.map((item, index) => /*#__PURE__*/React.createElement(TouchableOpacity, {
    key: index,
    activeOpacity: 1,
    style: classNames('flex h8 justifyCenter itemsCenter', {
      mr2: !justified && index < data.length - 1
    }),
    onPress: handlePress(item, index),
    onLayout: e => setPosition(e, index)
  }, /*#__PURE__*/React.createElement(View, {
    style: apply(classNames('h8 justifyCenter px3 ', {
      bgAction: current === index
    }), C.radius4, current === index ? tabSelectedStyle : tabStyle)
  }, /*#__PURE__*/React.createElement(Text, {
    color: current === index ? TextColor.white : TextColor.action,
    variant: TextVariant.ExtraSmall
  }, item.name)))));
};

export default Tabs;
//# sourceMappingURL=Tabs.js.map