import React from 'react';
import { storiesOf } from '@storybook/react-native';
import { Text as RNText, View } from 'react-native';
import { C, apply } from '../../styles';
import { Container, Title } from '../../utils';
import { TextColor } from '../../Colors';
import Text, { OnboardingText } from './Text';
import { TextVariant, FontWeight, TextAlign, OnboardingTextVariant } from './Text.types';
const textStories = storiesOf('Text', module).addDecorator(story =>
/*#__PURE__*/
// @ts-ignore
React.createElement(Container, null, story()));
textStories.add('Onboarding Text', () => /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Title, null, "Onboarding"), /*#__PURE__*/React.createElement(RNText, {
  style: apply(C.font4, C.mt8, C.mb2, C.familyRobotoBold)
}, "HERO"), /*#__PURE__*/React.createElement(OnboardingText, {
  variant: OnboardingTextVariant.Hero
}, "Lorem Ipsum es simplemente el texto de relleno de las imprentas y archivos de texto"), /*#__PURE__*/React.createElement(RNText, {
  style: apply(C.font4, C.mt8, C.mb2, C.familyRobotoBold)
}, "XL / ExtraLarge"), /*#__PURE__*/React.createElement(OnboardingText, {
  variant: OnboardingTextVariant.ExtraLarge
}, "Lorem Ipsum es simplemente el texto de relleno de las imprentas y archivos de texto"), /*#__PURE__*/React.createElement(RNText, {
  style: apply(C.font4, C.mt8, C.mb2, C.familyRobotoBold)
}, "L / Large"), /*#__PURE__*/React.createElement(OnboardingText, {
  variant: OnboardingTextVariant.Large
}, "Lorem Ipsum es simplemente el texto de relleno de las imprentas y archivos de texto")));
textStories.add('General Text', () => /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Title, null, "General"), /*#__PURE__*/React.createElement(RNText, {
  style: apply(C.font4, C.mt8, C.mb2, C.familyRobotoBold)
}, "HERO"), /*#__PURE__*/React.createElement(Text, {
  variant: TextVariant.Hero
}, "Lorem Ipsum es simplemente el texto de relleno de las imprentas y archivos de texto"), /*#__PURE__*/React.createElement(RNText, {
  style: apply(C.font4, C.mt8, C.mb2, C.familyRobotoBold)
}, "XL / Extra Large"), /*#__PURE__*/React.createElement(Text, {
  variant: TextVariant.XL
}, "Lorem Ipsum es simplemente el texto de relleno de las imprentas y archivos de texto"), /*#__PURE__*/React.createElement(RNText, {
  style: apply(C.font4, C.mt8, C.mb2, C.familyRobotoBold)
}, "L / Large"), /*#__PURE__*/React.createElement(Text, {
  style: C.mb2,
  variant: TextVariant.Large,
  weight: FontWeight.Bold
}, "Lorem Ipsum es simplemente el texto de relleno de las imprentas y archivos de texto"), /*#__PURE__*/React.createElement(Text, {
  variant: TextVariant.Large,
  weight: FontWeight.Regular
}, "Lorem Ipsum es simplemente el texto de relleno de las imprentas y archivos de texto"), /*#__PURE__*/React.createElement(RNText, {
  style: apply(C.font4, C.mt8, C.mb2, C.familyRobotoBold)
}, "M / Medium"), /*#__PURE__*/React.createElement(Text, {
  variant: TextVariant.Medium
}, "Lorem Ipsum es simplemente el texto de relleno de las imprentas y archivos de texto"), /*#__PURE__*/React.createElement(RNText, {
  style: apply(C.font4, C.mt8, C.mb2, C.familyRobotoBold)
}, "S / Small"), /*#__PURE__*/React.createElement(Text, {
  style: C.mb2,
  variant: TextVariant.Small,
  weight: FontWeight.Bold
}, "Lorem Ipsum es simplemente el texto de relleno de las imprentas y archivos de texto"), /*#__PURE__*/React.createElement(Text, {
  style: C.mb2,
  variant: TextVariant.Small,
  weight: FontWeight.Medium
}, "Lorem Ipsum es simplemente el texto de relleno de las imprentas y archivos de texto"), /*#__PURE__*/React.createElement(Text, {
  variant: TextVariant.Small,
  weight: FontWeight.Regular
}, "Lorem Ipsum es simplemente el texto de relleno de las imprentas y archivos de texto"), /*#__PURE__*/React.createElement(RNText, {
  style: apply(C.font4, C.mt8, C.mb2, C.familyRobotoBold)
}, "XS / Extra Small"), /*#__PURE__*/React.createElement(Text, {
  style: C.mb2,
  variant: TextVariant.XS
}, "Lorem Ipsum es simplemente el texto de relleno de las imprentas y archivos de texto"), /*#__PURE__*/React.createElement(RNText, {
  style: apply(C.font4, C.mt8, C.mb2, C.familyRobotoBold)
}, "XXS / Extra Extra Small"), /*#__PURE__*/React.createElement(Text, {
  variant: TextVariant.XXS
}, "Lorem Ipsum es simplemente el texto de relleno de las imprentas y archivos de texto"), /*#__PURE__*/React.createElement(View, {
  style: C.h8
})));
textStories.add('Alignment', () => /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Title, null, "Text Alignment"), /*#__PURE__*/React.createElement(Text, {
  style: C.mb4,
  variant: TextVariant.Medium,
  align: TextAlign.Left
}, "Text aligned in the left"), /*#__PURE__*/React.createElement(Text, {
  style: C.mb4,
  variant: TextVariant.Medium,
  align: TextAlign.Center
}, "Text aligned in the center"), /*#__PURE__*/React.createElement(Text, {
  variant: TextVariant.Medium,
  align: TextAlign.Right
}, "Text aligned in the right")));
textStories.add('Colors', () => /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Title, null, "Text Colors"), /*#__PURE__*/React.createElement(Text, {
  style: C.mb4,
  variant: TextVariant.Medium,
  color: TextColor.disrupt
}, "Text in Disrupt color"), /*#__PURE__*/React.createElement(Text, {
  style: C.mb4,
  variant: TextVariant.Medium,
  color: TextColor.action
}, "Text in Action color"), /*#__PURE__*/React.createElement(Text, {
  variant: TextVariant.Medium,
  color: TextColor.support
}, "Text in Support color")));
textStories.add('Uppercase', () => /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Title, null, "Normal or Uppercase"), /*#__PURE__*/React.createElement(Text, {
  style: C.mb4,
  variant: TextVariant.Medium
}, "Text by default"), /*#__PURE__*/React.createElement(Text, {
  variant: TextVariant.Medium,
  uppercase: true
}, "Text in uppercase")));
//# sourceMappingURL=Text.stories.js.map