import { storiesOf } from '@storybook/react-native';
import React from 'react';
import { View, Text, ViewStyle } from 'react-native';
import { C, apply, classNames } from './styles';
import { Container, Title } from './utils';
import LinearGradient from 'react-native-linear-gradient';
import { Gradient } from './Colors';

const colorsStories = storiesOf('Colors', module).addDecorator((story) => (
  // @ts-ignore
  <Container>{story()}</Container>
));

const general = ['Squid Ink', 'Action', 'Success', 'Warning', 'Disrupt'];

const grays = ['Support', 'Neutral', 'Iconic', 'Platin', 'Backdrop', 'White'];

const texts = [
  'Squid Ink',
  'Action',
  'Success',
  'Warning',
  'Disrupt',
  'Support',
  'Neutral',
];

const graphs = [
  'Pending',
  'Partial',
  'Paid',
  'Accepted',
  'Collected',
  'Billed',
  'Not Billed',
  'Partially Billed',
  'Draft',
];

const ColorBox = ({
  color,
  text,
  lightColor = false,
}: {
  color: ViewStyle;
  lightColor?: boolean;
  text: string;
}) => (
  <View style={C.mb4} key={text}>
    <View
      style={apply(
        color,
        classNames('radius2 h20 w20', {
          'borderBasic borderMinimum': lightColor,
        })
      )}
    />
    <Text style={apply(C.mt2, C.font3, C.alignCenter)}>{text}</Text>
  </View>
);

colorsStories.add('General Colors', () => (
  <>
    <Title>General Colors</Title>

    <View style={apply(C.row, C.mb4, C.justifyBetween, C.wrap)}>
      {general.map((graphName) => (
        <ColorBox
          key={graphName}
          color={C[`bg${graphName.split(' ').join('')}`]}
          text={graphName}
        />
      ))}
    </View>

    <View style={apply(C.row, C.mb4, C.justifyBetween, C.wrap)}>
      {grays.map((graphName) => (
        <ColorBox
          key={graphName}
          color={C[`bg${graphName.split(' ').join('')}`]}
          text={graphName}
          lightColor={['Platin', 'White'].includes(graphName)}
        />
      ))}
    </View>
  </>
));

colorsStories.add('Graphs Colors', () => (
  <>
    <Title>Graphs Colors</Title>

    <View style={apply(C.row, C.mb4, C.justifyBetween, C.wrap)}>
      {graphs.map((graphName) => (
        <ColorBox
          key={graphName}
          color={C[`bg${graphName.split(' ').join('')}`]}
          text={graphName}
        />
      ))}
      <View style={C.mb2}>
        <LinearGradient
          start={{ x: 0, y: 0 }}
          end={{ x: 1, y: 0 }}
          colors={Gradient.single}
          style={apply(C.radius2, C.h20, C.w20)}
        />

        <Text style={apply(C.mt2, C.font3, C.alignCenter)}>
          Single Gradient
        </Text>
      </View>
    </View>
  </>
));

colorsStories.add('Text Colors', () => (
  <>
    <Title>Text Colors</Title>

    <View style={apply(C.row, C.mb4, C.justifyBetween, C.wrap)}>
      {texts.map((graphName) => (
        <ColorBox
          key={graphName}
          color={C[`bg${graphName.split(' ').join('')}`]}
          text={graphName}
          lightColor={['White'].includes(graphName)}
        />
      ))}
    </View>
  </>
));
