import { storiesOf } from '@storybook/react-native';
import React, { useRef, useState } from 'react';
import { View } from 'react-native';

import { Container, Title, Separator } from '../../utils';
import { C } from '../../styles';
import type { ActionSheetProps } from './ActionSheet.types';
import ActionSheet from './ActionSheet';
import Button, { ButtonVariant } from '../Button';

const actionSheetStories = storiesOf('ActionSheet', module).addDecorator(
  (story) => (
    // @ts-ignore
    <Container>{story()}</Container>
  )
);

function Component() {
  const actionSheetRef = useRef<ActionSheetProps>(null);
  const actionsSimple = [
    {
      label: 'New Invoice',
    },
    { label: 'New  Quote' },
    { label: 'New Proforma' },
    { label: 'New Purchase' },
  ];
  const actionsWithIcons = [
    {
      label: 'Contact',
      icon: 'user',
    },
    {
      label: 'Company',
      icon: 'building',
    },
    {
      label: 'Debtor',
      icon: 'gavel',
    },
    {
      label: 'Alien',
      icon: 'raygun',
    },
  ];
  const [items, setItem] = useState(actionsSimple);
  return (
    <View style={C.flex}>
      <Title>{'ActionSheet'}</Title>
      <Button
        onPress={() => {
          actionSheetRef.current?.open();
        }}
        variant={ButtonVariant.Primary}
        text="Open"
      />

      <Separator />

      <Title>{'ActionSheet with icons'}</Title>
      <Button
        onPress={() => {
          actionSheetRef.current?.open();
          setItem(actionsWithIcons);
        }}
        variant={ButtonVariant.Primary}
        text="Open with icons"
      />
      <ActionSheet
        closeText={'Cancel'}
        items={items}
        title={'Title ActionSheet'}
        ref={actionSheetRef}
      />

      <Separator />

      <Title>{'ActionSheet without title'}</Title>
      <Button
        onPress={() => {
          actionSheetRef.current?.open();
          setItem(actionsSimple);
        }}
        variant={ButtonVariant.Primary}
        text="Open with icons"
      />
      <ActionSheet closeText={'Cancel'} items={items} ref={actionSheetRef} />
    </View>
  );
}

actionSheetStories.add('Variants', () => {
  return <Component />;
});
