import { storiesOf } from '@storybook/react-native';
import React from 'react';
import { View } from 'react-native';
import { C, apply } from '../../styles';

import { Container, Title, Subtitle } from '../../utils';
import AwesomeIcon from './AwesomeIcon';
import {
  AwesomeIconSize,
  AwesomeIconVariant,
  IconName,
  Transform,
} from './AwesomeIcon.types';

const awesomeIconStories = storiesOf('AwesomeIcon', module).addDecorator(
  (story) => (
    // @ts-ignore
    <Container>{story()}</Container>
  )
);

const brandIcons = ['react', 'twitter', 'facebook', 'youtube'] as IconName[];
const icons = ['key', 'home', 'times-circle', 'user'] as IconName[];

const renderIcons = (
  variant: AwesomeIconVariant,
  size: AwesomeIconSize = AwesomeIconSize.Medium
) =>
  icons.map((icon: IconName, index: number) => (
    <AwesomeIcon
      key={index}
      variant={variant}
      icon={icon}
      size={size}
      style={C.mb4}
    />
  ));

const renderBrandIcons = () =>
  brandIcons.map((icon: IconName, index: number) => (
    <AwesomeIcon
      key={index}
      variant={AwesomeIconVariant.Brand}
      icon={icon}
      size={AwesomeIconSize.Medium}
    />
  ));

const renderTransformedIcons = (transform: Transform) => (
  <AwesomeIcon
    variant={AwesomeIconVariant.Solid}
    icon={'snowboarding'}
    size={AwesomeIconSize.Medium}
    transform={transform}
  />
);

awesomeIconStories.add('Variants', () => (
  <>
    <Title>Icon Variants</Title>

    <View style={apply(C.row, C.mb4, C.justifyBetween, C.wrap)}>
      <Subtitle>Duotone</Subtitle>
      {renderIcons(AwesomeIconVariant.Duotone)}
    </View>

    <View style={apply(C.row, C.mb4, C.justifyBetween, C.wrap)}>
      <Subtitle>Light</Subtitle>
      {renderIcons(AwesomeIconVariant.Light)}
    </View>

    <View style={apply(C.row, C.mb4, C.justifyBetween, C.wrap)}>
      <Subtitle>Solid</Subtitle>
      {renderIcons(AwesomeIconVariant.Solid)}
    </View>

    <View style={apply(C.row, C.mb4, C.justifyBetween, C.wrap)}>
      <Subtitle>Regular</Subtitle>
      {renderIcons(AwesomeIconVariant.Regular)}
    </View>

    <View style={apply(C.row, C.mb4, C.justifyBetween, C.wrap)}>
      <Subtitle>Brand</Subtitle>
      {renderBrandIcons()}
    </View>
  </>
));

awesomeIconStories.add('Sizes', () => (
  <>
    <Title>Icon Sizes</Title>

    <View style={apply(C.row, C.mb4, C.justifyBetween, C.wrap)}>
      <Subtitle>Micro (10)</Subtitle>
      {renderIcons(AwesomeIconVariant.Regular, AwesomeIconSize.Micro)}
    </View>

    <View style={apply(C.row, C.mb4, C.justifyBetween, C.wrap)}>
      <Subtitle>Extra Extra Small (12)</Subtitle>
      {renderIcons(AwesomeIconVariant.Regular, AwesomeIconSize.ExtraExtraSmall)}
    </View>

    <View style={apply(C.row, C.mb4, C.justifyBetween, C.wrap)}>
      <Subtitle>Extra Small (16)</Subtitle>
      {renderIcons(AwesomeIconVariant.Regular, AwesomeIconSize.ExtraSmall)}
    </View>

    <View style={apply(C.row, C.mb4, C.justifyBetween, C.wrap)}>
      <Subtitle>Small (20)</Subtitle>
      {renderIcons(AwesomeIconVariant.Regular, AwesomeIconSize.Small)}
    </View>

    <View style={apply(C.row, C.mb4, C.justifyBetween, C.wrap)}>
      <Subtitle>Medium (24)</Subtitle>
      {renderIcons(AwesomeIconVariant.Regular, AwesomeIconSize.Medium)}
    </View>

    <View style={apply(C.row, C.mb4, C.justifyBetween, C.wrap)}>
      <Subtitle>Large (32)</Subtitle>
      {renderIcons(AwesomeIconVariant.Regular, AwesomeIconSize.Large)}
    </View>

    <View style={apply(C.row, C.mb4, C.justifyBetween, C.wrap)}>
      <Subtitle>Extra Large (48)</Subtitle>
      {renderIcons(AwesomeIconVariant.Regular, AwesomeIconSize.ExtraLarge)}
    </View>
  </>
));

awesomeIconStories.add('Transformations', () => (
  <>
    <Title>Icon Transformations</Title>

    <Subtitle>Rotation</Subtitle>
    <View style={apply(C.row, C.mb4, C.justifyBetween, C.wrap)}>
      {renderTransformedIcons({} as Transform)}
      {renderTransformedIcons({ rotate: 90 })}
      {renderTransformedIcons({ rotate: 180 })}
      {renderTransformedIcons({ rotate: 270 })}
    </View>

    <Subtitle>Flip</Subtitle>
    <View style={apply(C.row, C.mb4, C.justifyBetween, C.wrap)}>
      {renderTransformedIcons({} as Transform)}
      {renderTransformedIcons({ flipX: true })}
      {renderTransformedIcons({ flipY: true })}
      {renderTransformedIcons({ flipX: true, flipY: true })}
    </View>
  </>
));
