import React, {
  forwardRef,
  ForwardRefRenderFunction,
  useEffect,
  useImperativeHandle,
  useState,
} from 'react';
import {
  SafeAreaView,
  TouchableOpacity,
  View,
  StatusBar,
  Platform,
} from 'react-native';
import RNModal from 'react-native-modal';
import KeyboardSpacer from 'react-native-keyboard-spacer';

import { C, apply, Color } from '../../index';
import AwesomeIcon, {
  AwesomeIconSize,
  AwesomeIconVariant,
} from '../AwesomeIcon/index';
import Text, { TextVariant, FontWeight } from '../Text/index';
import type { VisibleToggle } from 'src/types';
import type { BottomModalProps } from './BottomModal.types';

const BottomModal: ForwardRefRenderFunction<
  VisibleToggle,
  Partial<BottomModalProps>
> = ({ title = '', children, isVisible = false, ...props }, ref) => {
  const [visible, setVisible] = useState<boolean>(isVisible);
  const close = () => setVisible(false);
  const open = () => setVisible(true);

  useImperativeHandle(
    ref,
    () => ({
      open,
      close,
    }),
    []
  );

  useEffect(() => {
    setVisible(visible);
  }, [isVisible, visible]);
  useEffect(() => {
    if (Platform.OS !== 'ios') {
      StatusBar.setTranslucent(true);
    }
    return () => StatusBar.setTranslucent(false);
  }, []);
  return (
    <RNModal
      isVisible={visible}
      style={apply(C.justifyEnd, C.m0)}
      onBackdropPress={close}
      onBackButtonPress={close}
      {...props}
    >
      <SafeAreaView
        style={apply(C.itemBottom, C.justifyEnd, C.bgWhite, {
          borderTopLeftRadius: 12,
          borderTopRightRadius: 12,
        })}
      >
        <View
          style={apply(
            C.row,
            C.justifyBetween,
            C.itemsCenter,
            C.mt3,
            C.py3,
            C.px4,
            C.mb1
          )}
        >
          <Text
            variant={TextVariant.Large}
            weight={FontWeight.Regular}
            numberOfLines={1}
          >
            {title}
          </Text>
          <TouchableOpacity onPress={close} style={C.ml2}>
            <AwesomeIcon
              variant={AwesomeIconVariant.Regular}
              icon="times"
              size={AwesomeIconSize.Medium}
              color={Color.support}
            />
          </TouchableOpacity>
        </View>
        {children}
        <KeyboardSpacer />
      </SafeAreaView>
    </RNModal>
  );
};

export default forwardRef(BottomModal);
