import React from 'react';
import { storiesOf } from '@storybook/react-native';
import { Container, Title, Separator } from '../../utils';

import Button from './Button';
import { ButtonVariant, ButtonSize, SocialButton } from './Button.types';
import { AwesomeIconVariant } from '../AwesomeIcon';

const buttonStories = storiesOf('Button', module).addDecorator((story) => (
  // @ts-ignore
  <Container>{story()}</Container>
));

buttonStories.add('Variants', () => (
  <>
    <Title>Button Variants</Title>

    <Button
      onPress={() => {}}
      variant={ButtonVariant.Primary}
      text="Primary Button"
    />

    <Separator />

    <Button
      onPress={() => {}}
      variant={ButtonVariant.Secondary}
      text="Secondary Button"
    />
  </>
));

buttonStories.add('Sizes', () => (
  <>
    <Title>Button Sizes</Title>

    <Button onPress={() => {}} size={ButtonSize.Small} text="Small Button" />

    <Separator />

    <Button onPress={() => {}} size={ButtonSize.Medium} text="Medium Button" />

    <Separator />

    <Button onPress={() => {}} size={ButtonSize.Large} text="Large Button" />
  </>
));

buttonStories.add('States', () => (
  <>
    <Title>Button States</Title>

    <Button onPress={() => {}} text="Default State" />

    <Separator />

    <Button onPress={() => {}} disabled text="Disabled State" />
  </>
));

buttonStories.add('Social', () => (
  <>
    <Title>Social Buttons</Title>

    <Button
      variant={ButtonVariant.Social}
      provider={SocialButton.Apple}
      onPress={() => {}}
      text="Signup with Apple"
    />

    <Separator />

    <Button
      variant={ButtonVariant.Social}
      provider={SocialButton.Google}
      onPress={() => {}}
      text="Login with Google"
    />
  </>
));

buttonStories.add('With Icon', () => (
  <>
    <Title>With Icon</Title>

    <Button onPress={() => {}} iconName="plus" text="Add" />

    <Separator />

    <Button
      onPress={() => {}}
      iconName="trash"
      variant={ButtonVariant.Secondary}
      text="Remove"
    />

    <Separator />

    <Button
      onPress={() => {}}
      iconName="envelope"
      iconVariant={AwesomeIconVariant.Solid}
      text="Send"
    />
  </>
));
