import type { VoidFunction, WithTestID } from '../../types';
import type { PropsWithChildren } from 'react';
import type { TouchableOpacityProps } from 'react-native';
import type { AwesomeIconVariant, IconName } from '../AwesomeIcon';

export enum ButtonVariant {
  Primary = 'primary',
  Secondary = 'secondary',
  Outline = 'outline',
  Social = 'social',
}

export enum ButtonSize {
  Small = 'small',
  Medium = 'medium',
  Large = 'large',
}

export enum SocialButton {
  Apple = 'Apple',
  Google = 'Google',
}

type ButtonsProps = TouchableOpacityProps &
  PropsWithChildren<
    WithTestID<{
      disabled?: boolean;
      iconName?: IconName;
      iconVariant?: AwesomeIconVariant;
      onPress: VoidFunction;
      provider?: SocialButton;
      size?: ButtonSize;
      text: string;
      uppercase?: boolean;
    }>
  >;

export type BasicButtonProps = ButtonsProps & {
  variant?:
    | ButtonVariant.Primary
    | ButtonVariant.Secondary
    | ButtonVariant.Outline;
};

export type SocialButtonProps = ButtonsProps & {
  variant: ButtonVariant.Social;
  provider: SocialButton;
};

export type ButtonProps = BasicButtonProps | SocialButtonProps;
