import React, { useState } from 'react';
import { View } from 'react-native';
import LinearGradient from 'react-native-linear-gradient';
import Widget from '../Widget';
import { C, apply, Gradient } from '../../index';

const ProgressBarChart = ({ current, total, title, Text, text }: any) => {
  const [viewLayout, setViewLayout] = useState<any>({
    height: 0,
    width: 0,
  });
  const percentage = current / total;
  const progressWidth = viewLayout.width * (percentage < 1 ? percentage : 1);

  return (
    <Widget title={title} text={text}>
      <View
        style={apply(C.wFull, C.h2, C.bgGray200, C.radius2, C.mt4)}
        onLayout={({ nativeEvent: { layout } }) => setViewLayout(layout)}
      >
        <LinearGradient
          colors={Gradient.single}
          start={{ x: 0, y: 1 }}
          end={{ x: 1, y: 1 }}
          style={apply(C.h2, { width: progressWidth }, C.radius2)}
        />
      </View>

      <View style={apply(C.row, C.itemsEnd, C.mt5)}>
        <Text>{`${((total / current) * 100).toFixed(1)} %`}</Text>

        <View style={apply(C.ml4)}>
          {text && <Text>{text}</Text>}

          <Text>{total.toString()}</Text>
        </View>
      </View>
    </Widget>
  );
};

export default ProgressBarChart;
