import React from 'react';
import { storiesOf } from '@storybook/react-native';
import { Container, Separator, Subtitle, Title } from '../../utils';
import { C } from '../../styles';

import Input from './Input';
import { View } from 'react-native';
import { InputSize } from './Input.types';

const inputStories = storiesOf('Input', module).addDecorator((story) => (
  // @ts-ignore
  <Container>{story()}</Container>
));

inputStories.add('Status', () => (
  <>
    <Title style={C.px4}>Input Status</Title>

    <Subtitle style={C.px4}>Basic input</Subtitle>
    <Input placeholder="Full Name" />

    <Separator />

    <Subtitle style={C.px4}>Password input</Subtitle>
    <Input icon="key" placeholder="Choose a password" secureTextEntry />

    <Separator />

    <Subtitle style={C.px4}>Focused input</Subtitle>
    <Input
      icon="user"
      placeholder="User Name"
      defaultValue="Zlatan Ibrahimovic"
      focused
    />

    <Separator />

    <Subtitle style={C.px4}>Error input</Subtitle>
    <Input icon="home" placeholder="Address" error />

    <Separator />

    <Subtitle style={C.px4}>Error input with value</Subtitle>
    <Input
      icon="home"
      placeholder="Address"
      defaultValue="Passeig Joan de Borbó"
      error
    />

    <Separator />

    <Subtitle style={C.px4}>Disabled</Subtitle>
    <Input disabled icon="envelope" placeholder="Email" />
    <Separator />

    <Subtitle style={C.px4}>Readonly</Subtitle>
    <Input
      readonly
      defaultValue="john.doe@example.com"
      icon="envelope"
      placeholder="Email"
    />

    <View style={C.h8} />
  </>
));

inputStories.add('Sizes', () => (
  <>
    <Title style={C.px4}>Input Sizes</Title>

    <Subtitle style={C.px4}>Normal Size</Subtitle>

    <Input placeholder="Full Name" />

    <View style={C.h2} />

    <Input icon="home" placeholder="Address" />

    <View style={C.h2} />

    <Input icon="user" placeholder="User Name" error />

    <Separator />

    <Subtitle style={C.px4}>Small Size</Subtitle>

    <Input size={InputSize.Small} placeholder="This is a placeholder" />

    <View style={C.h2} />

    <Input size={InputSize.Small} placeholder="Address" icon="home" />

    <View style={C.h2} />

    <Input size={InputSize.Small} placeholder="User Name" icon="user" error />
  </>
));
