import React from 'react';
import { storiesOf } from '@storybook/react-native';
import { insets, Subtitle } from '../../utils';

import Layout from './Layout';
import { apply, C } from '../../styles';
import { Alert, TouchableOpacity, View } from 'react-native';
import Text, { TextVariant, FontWeight } from '../Text/index';
import AwesomeIcon, {
  AwesomeIconSize,
  AwesomeIconVariant,
} from '../AwesomeIcon';
import Color from '../../Colors';

const layoutStories = storiesOf('Layout', module);

layoutStories.add('Basic Layout', () => (
  <Layout title="Basic Layout" insets={insets}>
    <Subtitle>Children content</Subtitle>
  </Layout>
));

layoutStories.add('With Back Layout', () => (
  <Layout title="With back Layout" insets={insets} withBack>
    <Subtitle>Children content</Subtitle>
  </Layout>
));

layoutStories.add('With Actions Layout', () => {
  const actions = (
    <TouchableOpacity
      onPress={() => Alert.alert('Alert title', 'Alert content')}
    >
      <AwesomeIcon
        icon="plus"
        variant={AwesomeIconVariant.Light}
        size={AwesomeIconSize.Medium}
        color={Color.action}
      />
    </TouchableOpacity>
  );

  return (
    <Layout
      title="With actions Layout"
      actions={actions}
      insets={insets}
      withBack
    >
      <Subtitle>Children content</Subtitle>
    </Layout>
  );
});

layoutStories.add('With icons', () => (
  <Layout
    title={
      <View style={apply(C.row, C.itemsCenter)}>
        <Text
          numberOfLines={1}
          variant={TextVariant.ExtraLarge}
          weight={FontWeight.Medium}
        >
          {'#F200005'}
        </Text>
        <AwesomeIcon
          icon={'circle'}
          variant={AwesomeIconVariant.Solid}
          size={AwesomeIconSize.ExtraExtraSmall}
          style={C.ml2}
          color={Color.disrupt}
        />
      </View>
    }
    insets={insets}
    withBack
  >
    <Subtitle>Children</Subtitle>
  </Layout>
));
