import React, { ReactNode, useState } from 'react';
import { View, TouchableOpacity } from 'react-native';
import { storiesOf } from '@storybook/react-native';
import { Container, Separator, Title } from '../../utils';
import Button, { ButtonVariant } from '../Button';
import Text, { TextVariant, FontWeight } from '../Text';
import Input from '../Input';
import Modal from './Modal';
import type { ModalProps } from './Modal.types';
import { C, apply } from '../../styles';
import { TextColor } from '../../Colors';

const modalStories = storiesOf('Modal', module).addDecorator((story) => (
  // @ts-ignore
  <Container>{story()}</Container>
));

function Component() {
  const modalRef = React.useRef<ModalProps>(null);
  const [footer, setFooter] = useState<ReactNode>(null);
  const [title, setTitle] = useState<string>('Title Modal');
  const footerComp = (
    <View style={apply(C.px4, C.my4)}>
      <TouchableOpacity
        style={apply(
          C.bgAction,
          C.radius2,
          C.h12,
          C.row,
          C.itemsCenter,
          C.justifyCenter
        )}
      >
        <Text
          variant={TextVariant.Small}
          weight={FontWeight.Bold}
          color={TextColor.white}
        >
          Save
        </Text>
      </TouchableOpacity>
    </View>
  );
  return (
    <View style={C.flex1}>
      <Title>Modal</Title>
      <Button
        onPress={() => {
          modalRef.current?.open();
          setFooter(null);
        }}
        variant={ButtonVariant.Primary}
        text="Open"
      />

      <Separator />

      <Title>Modal with Footer</Title>
      <Button
        onPress={() => {
          modalRef.current?.open();
          setFooter(footerComp);
          setTitle('Title Modal with Footer');
        }}
        variant={ButtonVariant.Primary}
        text="Open"
      />

      <Modal
        ref={modalRef}
        title={title}
        footer={footer}
        style={apply(C.m0, C.flex, { paddingTop: 50 })}
      >
        <View style={apply(C.flex)}>
          <Separator />
          <Input icon="user" placeholder={'Contact'} />
          <Input
            icon="clock"
            containerStyle={C.bordertop0}
            placeholder={'Calendar'}
          />
          <Input
            icon="calendar"
            placeholder={'Due Calendar'}
            containerStyle={C.bordertop0}
          />
          <Input
            icon="percent"
            containerStyle={C.bordertop0}
            placeholder={'Discount'}
          />
          {footer === null ? (
            <>
              <Input
                icon="envelope"
                placeholder={'Extra Input 1'}
                containerStyle={C.bordertop0}
              />
              <Input
                icon="key"
                containerStyle={C.bordertop0}
                placeholder={'Extra Input 2'}
              />
              <Input
                icon="envelope"
                placeholder={'Extra Input 3'}
                containerStyle={C.bordertop0}
              />
              <Input
                icon="key"
                containerStyle={C.bordertop0}
                placeholder={'Extra Input 4'}
              />
              <Input
                icon="envelope"
                placeholder={'Extra Input 5'}
                containerStyle={C.bordertop0}
              />
            </>
          ) : null}
        </View>
      </Modal>
    </View>
  );
}

modalStories.add('Variants', () => {
  return <Component />;
});
