import React, { useEffect, useRef, useState } from 'react';
import {
  LayoutChangeEvent,
  ScrollView,
  TouchableOpacity,
  View,
} from 'react-native';
import { C, apply, classNames } from '../../styles';
import { TextColor } from '../../Colors';
import Text, { TextVariant } from '../Text';
import type { TabItem, TabsProps } from './Tabs.types';

// This is to scroll to more left item position in order to be able to display the previous item in order to tap it without need to scroll manually.
const SCROLL_OVERFLOW = 24;

const Tabs = ({
  containerStyle,
  data,
  justified,
  onChange,
  scrollOverflow = SCROLL_OVERFLOW,
  selected,
  tabStyle,
  tabSelectedStyle,
}: TabsProps) => {
  const [current, setCurrent] = useState<number>(selected || 0);
  const scrollViewRef = useRef<ScrollView>(null);
  const elementPosition = useRef<any[]>([]);

  const handlePress = (item: TabItem, index: number) => () => {
    if (!item.disabled) {
      setCurrent(index);
      onChange?.(item, index);
      scrollViewRef.current?.scrollTo({
        x: elementPosition.current[index] - scrollOverflow,
      });
    }
  };

  const setPosition = (e: LayoutChangeEvent, index: number) => {
    const { x } = e.nativeEvent.layout;

    if (!elementPosition.current[index]) {
      elementPosition.current[index] = x;
    }
  };

  useEffect(() => {
    setCurrent(selected || 0);
  }, [selected]);

  return (
    <ScrollView
      ref={scrollViewRef}
      showsHorizontalScrollIndicator={false}
      bounces={false}
      alwaysBounceHorizontal={false}
      contentContainerStyle={classNames('', {
        wFull: justified,
        justifyBetween: justified,
      })}
      horizontal
      style={apply(C.row, containerStyle)}
    >
      {data?.map((item, index) => (
        <TouchableOpacity
          key={index}
          activeOpacity={1}
          style={classNames('flex h8 justifyCenter itemsCenter', {
            mr2: !justified && index < data.length - 1,
          })}
          onPress={handlePress(item, index)}
          onLayout={(e) => setPosition(e, index)}
        >
          <View
            style={apply(
              classNames('h8 justifyCenter px3 ', {
                bgAction: current === index,
              }),
              C.radius4,
              current === index ? tabSelectedStyle : tabStyle
            )}
          >
            <Text
              color={current === index ? TextColor.white : TextColor.action}
              variant={TextVariant.ExtraSmall}
            >
              {item.name}
            </Text>
          </View>
        </TouchableOpacity>
      ))}
    </ScrollView>
  );
};

export default Tabs;
