import React from 'react';
import { storiesOf } from '@storybook/react-native';
import { Text as RNText, View } from 'react-native';
import { C, apply } from '../../styles';
import { Container, Title } from '../../utils';
import { TextColor } from '../../Colors';
import Text, { OnboardingText } from './Text';
import {
  TextVariant,
  FontWeight,
  TextAlign,
  OnboardingTextVariant,
} from './Text.types';

const textStories = storiesOf('Text', module).addDecorator((story) => (
  // @ts-ignore
  <Container>{story()}</Container>
));

textStories.add('Onboarding Text', () => (
  <>
    <Title>Onboarding</Title>

    <RNText style={apply(C.font4, C.mt8, C.mb2, C.familyRobotoBold)}>
      HERO
    </RNText>
    <OnboardingText variant={OnboardingTextVariant.Hero}>
      Lorem Ipsum es simplemente el texto de relleno de las imprentas y archivos
      de texto
    </OnboardingText>

    <RNText style={apply(C.font4, C.mt8, C.mb2, C.familyRobotoBold)}>
      XL / ExtraLarge
    </RNText>
    <OnboardingText variant={OnboardingTextVariant.ExtraLarge}>
      Lorem Ipsum es simplemente el texto de relleno de las imprentas y archivos
      de texto
    </OnboardingText>

    <RNText style={apply(C.font4, C.mt8, C.mb2, C.familyRobotoBold)}>
      L / Large
    </RNText>
    <OnboardingText variant={OnboardingTextVariant.Large}>
      Lorem Ipsum es simplemente el texto de relleno de las imprentas y archivos
      de texto
    </OnboardingText>
  </>
));

textStories.add('General Text', () => (
  <>
    <Title>General</Title>

    <RNText style={apply(C.font4, C.mt8, C.mb2, C.familyRobotoBold)}>
      HERO
    </RNText>
    <Text variant={TextVariant.Hero}>
      Lorem Ipsum es simplemente el texto de relleno de las imprentas y archivos
      de texto
    </Text>

    <RNText style={apply(C.font4, C.mt8, C.mb2, C.familyRobotoBold)}>
      XL / Extra Large
    </RNText>
    <Text variant={TextVariant.XL}>
      Lorem Ipsum es simplemente el texto de relleno de las imprentas y archivos
      de texto
    </Text>

    <RNText style={apply(C.font4, C.mt8, C.mb2, C.familyRobotoBold)}>
      L / Large
    </RNText>
    <Text style={C.mb2} variant={TextVariant.Large} weight={FontWeight.Bold}>
      Lorem Ipsum es simplemente el texto de relleno de las imprentas y archivos
      de texto
    </Text>
    <Text variant={TextVariant.Large} weight={FontWeight.Regular}>
      Lorem Ipsum es simplemente el texto de relleno de las imprentas y archivos
      de texto
    </Text>

    <RNText style={apply(C.font4, C.mt8, C.mb2, C.familyRobotoBold)}>
      M / Medium
    </RNText>
    <Text variant={TextVariant.Medium}>
      Lorem Ipsum es simplemente el texto de relleno de las imprentas y archivos
      de texto
    </Text>

    <RNText style={apply(C.font4, C.mt8, C.mb2, C.familyRobotoBold)}>
      S / Small
    </RNText>
    <Text style={C.mb2} variant={TextVariant.Small} weight={FontWeight.Bold}>
      Lorem Ipsum es simplemente el texto de relleno de las imprentas y archivos
      de texto
    </Text>
    <Text style={C.mb2} variant={TextVariant.Small} weight={FontWeight.Medium}>
      Lorem Ipsum es simplemente el texto de relleno de las imprentas y archivos
      de texto
    </Text>
    <Text variant={TextVariant.Small} weight={FontWeight.Regular}>
      Lorem Ipsum es simplemente el texto de relleno de las imprentas y archivos
      de texto
    </Text>

    <RNText style={apply(C.font4, C.mt8, C.mb2, C.familyRobotoBold)}>
      XS / Extra Small
    </RNText>
    <Text style={C.mb2} variant={TextVariant.XS}>
      Lorem Ipsum es simplemente el texto de relleno de las imprentas y archivos
      de texto
    </Text>

    <RNText style={apply(C.font4, C.mt8, C.mb2, C.familyRobotoBold)}>
      XXS / Extra Extra Small
    </RNText>
    <Text variant={TextVariant.XXS}>
      Lorem Ipsum es simplemente el texto de relleno de las imprentas y archivos
      de texto
    </Text>

    <View style={C.h8} />
  </>
));

textStories.add('Alignment', () => (
  <>
    <Title>Text Alignment</Title>

    <Text style={C.mb4} variant={TextVariant.Medium} align={TextAlign.Left}>
      Text aligned in the left
    </Text>

    <Text style={C.mb4} variant={TextVariant.Medium} align={TextAlign.Center}>
      Text aligned in the center
    </Text>

    <Text variant={TextVariant.Medium} align={TextAlign.Right}>
      Text aligned in the right
    </Text>
  </>
));

textStories.add('Colors', () => (
  <>
    <Title>Text Colors</Title>

    <Text style={C.mb4} variant={TextVariant.Medium} color={TextColor.disrupt}>
      Text in Disrupt color
    </Text>

    <Text style={C.mb4} variant={TextVariant.Medium} color={TextColor.action}>
      Text in Action color
    </Text>

    <Text variant={TextVariant.Medium} color={TextColor.support}>
      Text in Support color
    </Text>
  </>
));

textStories.add('Uppercase', () => (
  <>
    <Title>Normal or Uppercase</Title>

    <Text style={C.mb4} variant={TextVariant.Medium}>
      Text by default
    </Text>

    <Text variant={TextVariant.Medium} uppercase>
      Text in uppercase
    </Text>
  </>
));
